antares.apps.notifications.manager package
==========================================

Submodules
----------

antares.apps.notifications.manager.notification\_manager module
---------------------------------------------------------------

.. automodule:: antares.apps.notifications.manager.notification_manager
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.notifications.manager
   :members:
   :undoc-members:
   :show-inheritance:
